// 
// Copyright (C) 2008, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//
#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Strategy;
#endregion
// Add System.Collections so we can use ArrayLists
using System.Collections;

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Reference sample demonstrating how to monitor stop-loss and profit target orders
    /// </summary>
    [Description("Reference sample demonstrating how to monitor stop-loss and profit target orders")]
    public class SampleMonitorStopProfit : Strategy
    {
        #region Variables
		/* Create two ArrayLists for storing our stop-loss and profit target orders. An order collection is necessary
		because of the possibilities of a partial fill where two or more stop/profit orders will be submitted for one entry
		condition. The ArrayLists will allow us to keep track of each individual order. */
		private ArrayList stopLossOrders = new ArrayList();
		private ArrayList profitTargetOrders = new ArrayList();
		private bool doneForSession = false;
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
			// Submit stop-loss and profit target orders
			SetStopLoss(CalculationMode.Ticks, 5);
			SetProfitTarget(CalculationMode.Ticks, 10);
			
            CalculateOnBarClose = true;
			
			// Allow two simultaneous entries
			EntriesPerDirection = 2;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// Reset our bool variable that limits our strategy to two entries at the beginning of each session
			if (Bars.FirstBarOfSession && FirstTickOfBar)
				doneForSession = false;
			
			// If two entries have been made in this session already stop submitting more entry orders
			if (doneForSession)
				return;
			
			// Enter long 1 contract
			if (Close[0] > Open[0])
				EnterLong(1);
			
			// Enter long another 1 contract after the first contract was filled
			if (Position.Quantity == 1)
				EnterLong(1);
			
			// After both orders have been filled prevent the strategy from submitting more orders during this session
			else if (Position.Quantity == 2)
				doneForSession = true;
        }

		protected override void OnOrderUpdate(IOrder order)
		{
			// If OnOrderUpdate() is called from a stop loss or profit target order add it to the appropriate collection
			if (order.OrderState == OrderState.PendingSubmit)
			{
				// Add the "Stop loss" orders to the Stop Loss collection
				if (order.Name == "Stop loss")
					stopLossOrders.Add(order);
				
				// Add the "Profit target" orders to the Profit Target collection
				else if (order.Name == "Profit target")
					profitTargetOrders.Add(order);
			}
			

			// Process stop loss orders
			if (stopLossOrders.Contains(order))
			{
				// Check order for terminal state
				if (order.OrderState == OrderState.Cancelled || order.OrderState == OrderState.Filled || order.OrderState == OrderState.Rejected)
				{
					// Print out information about the order
					Print(order.ToString());
					
					// Remove from collection
					stopLossOrders.Remove(order);
				}
				
				// Print out the current stop loss price
				else
					Print("The order name " + order.Name + " stop price is currently " + order.StopPrice);
			}
			
			
			// Process profit target orders
			if (profitTargetOrders.Contains(order))
			{
				// Check order for terminal state
				if (order.OrderState == OrderState.Cancelled || order.OrderState == OrderState.Filled || order.OrderState == OrderState.Rejected)
				{
					// Print out information about the order
					Print(order.ToString());
					
					// Remove from collection
					profitTargetOrders.Remove(order);
				}
				
				// Print out the current stop loss price
				else
					Print("The order name " + order.Name + " limit price is currently " + order.LimitPrice);
			}
		}
        #region Properties
        #endregion
    }
}
